summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KRootPixmap.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KRootPixmap.java')
-rw-r--r--kdejava/koala/org/kde/koala/KRootPixmap.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdejava/koala/org/kde/koala/KRootPixmap.java b/kdejava/koala/org/kde/koala/KRootPixmap.java
index c8fec503..86179589 100644
--- a/kdejava/koala/org/kde/koala/KRootPixmap.java
+++ b/kdejava/koala/org/kde/koala/KRootPixmap.java
@@ -23,7 +23,7 @@ import org.kde.qt.TQObject;
Instead of using the default behavior, you can ask KRootPixmap
to emit a backgroundUpdated(TQPixmap) signal whenever
the background needs updating by using setCustomPainting(boolean).
- Alternatively by reimplementing updateBackground(KSharedPixmap)
+ Alternatively by reimplementing updateBackground(TDESharedPixmap)
you can take complete control of the behavior.
See {@link KRootPixmapSignals} for signals emitted by KRootPixmap
@author Geert Jansen <jansen@kde.org>
@@ -150,9 +150,9 @@ public class KRootPixmap extends TQObject {
*/
public native void setCustomPainting(boolean enable);
/**
- Asks KDesktop to export the desktop background as a KSharedPixmap.
+ Asks KDesktop to export the desktop background as a TDESharedPixmap.
This method uses DCOP to call KBackgroundIface/setExport(int).
- @short Asks KDesktop to export the desktop background as a KSharedPixmap.
+ @short Asks KDesktop to export the desktop background as a TDESharedPixmap.
*/
public native void enableExports();
/**
@@ -172,7 +172,7 @@ public class KRootPixmap extends TQObject {
backgroundUpdated(TQPixmap) depending on the painting mode.
@short Called when the pixmap has been updated.
*/
// void updateBackground(KSharedPixmap* arg1); >>>> NOT CONVERTED
/** Deletes the wrapped C++ instance */
protected native void finalize() throws InternalError;
/** Delete the wrapped C++ instance ahead of finalize() */
@@ -172,7 +172,7 @@ public class KRootPixmap extends TQObject {
*/
- // void updateBackground(KSharedPixmap* arg1); >>>> NOT CONVERTED
+ // void updateBackground(TDESharedPixmap* arg1); >>>> NOT CONVERTED
/** Deletes the wrapped C++ instance */
protected native void finalize() throws InternalError;